# -*- coding: utf-8 -*-


from marshmallow import Schema, fields, post_load, post_dump, EXCLUDE

from .split_definition_schema_exclude import SplitDefinitionSchemaExclude
from splitiorequests.models.splits.split_definitions import SplitDefinitions


class SplitDefinitionsSchemaExclude(Schema):
    class Meta:
        unknown = EXCLUDE
        ordered = True

    objects = fields.List(fields.Nested(SplitDefinitionSchemaExclude), required=True)
    offset = fields.Int(required=True)
    limit = fields.Int(required=True)
    totalCount = fields.Int(required=True)

    @post_load
    def load_split_definitions(self, data, **kwargs):
        return SplitDefinitions(**data)

    @post_dump
    def clean_empty(self, data, **kwargs):
        return dict(data)
